@@ -18,7 +18,7 @@ class IsNaN(Base):
             outputs=["y"],
         )
 
-        x = np.array([-1.2, np.nan, np.inf, 2.8, np.NINF, np.inf], dtype=np.float32)
+        x = np.array([-1.2, np.nan, np.inf, 2.8, -np.inf, np.inf], dtype=np.float32)
         y = np.isnan(x)
         expect(node, inputs=[x], outputs=[y], name="test_isnan")
 
@@ -30,6 +30,6 @@ class IsNaN(Base):
             outputs=["y"],
         )
 
-        x = np.array([-1.2, np.nan, np.inf, 2.8, np.NINF, np.inf], dtype=np.float16)
+        x = np.array([-1.2, np.nan, np.inf, 2.8, -np.inf, np.inf], dtype=np.float16)
         y = np.isnan(x)
         expect(node, inputs=[x], outputs=[y], name="test_isnan_float16")
